@@ -19,8 +19,8 @@ along with CVXPY.  If not, see <http://www.gnu.org/licenses/>.
 
 import cvxpy.settings as s
 import cvxpy.lin_ops.lin_utils as lu
+import cvxpy.utilities.performance_utils as pu
 from cvxpy.constraints.constraint import Constraint
-from toolz import memoize
 
 class SOC(Constraint):
     """A second-order cone constraint, i.e., norm2(x) <= t.
@@ -51,11 +51,11 @@ class SOC(Constraint):
         solver : str
             The solver being called.
         """
-        leq_constr += self.__format()[1]
+        leq_constr += self.__format[1]
         # Update dims.
         dims[s.SOC_DIM].append(self.size[0])
 
-    @memoize
+    @pu.lazyprop
     def __format(self):
         """Internal version of format with cached results.
 
