@@ -19,8 +19,8 @@ along with CVXPY.  If not, see <http://www.gnu.org/licenses/>.
 
 import cvxpy.settings as s
 import cvxpy.lin_ops.lin_utils as lu
+import cvxpy.utilities.performance_utils as pu
 from cvxpy.constraints.constraint import Constraint
-from toolz import memoize
 
 class SDP(Constraint):
     """
@@ -54,14 +54,14 @@ class SDP(Constraint):
             The solver being called.
         """
         # A == A.T
-        eq_constr += self.__format()[0]
+        eq_constr += self.__format[0]
         # 0 <= A
-        leq_constr += self.__format()[1]
+        leq_constr += self.__format[1]
         # Update dims.
         dims[s.EQ_DIM] += self.size[0]*self.size[1]
         dims[s.SDP_DIM].append(self.size[0])
 
-    @memoize
+    @pu.lazyprop
     def __format(self):
         """Internal version of format with cached results.
 
