@@ -24,8 +24,9 @@ import scipy.sparse as sp
 import cvxopt
 import scipy
 import unittest
+from base_test import BaseTest
 
-class TestInterfaces(unittest.TestCase):
+class TestInterfaces(BaseTest):
     """ Unit tests for matrix interfaces. """
     def setUp(self):
         pass
@@ -63,6 +64,8 @@ class TestInterfaces(unittest.TestCase):
         mat = interface.const_to_matrix([[1,2,3],[3,4,5]])
         mat = interface.reshape(mat, (6,1))
         self.assertEquals(interface.index(mat, (4,0)), 4)
+        mat = interface.const_to_matrix(1, convert_scalars=True)
+        self.assertEquals(type(interface.reshape(mat, (1,1))), type(mat))
         # index
         mat = interface.const_to_matrix([[1,2,3,4],[3,4,5,6]])
         self.assertEquals( interface.index(mat, (0,1)), 3)
@@ -91,6 +94,8 @@ class TestInterfaces(unittest.TestCase):
         mat = interface.const_to_matrix([[1,2,3],[3,4,5]])
         mat = interface.reshape(mat, (6,1))
         self.assertEquals(interface.index(mat, (4,0)), 4)
+        mat = interface.const_to_matrix(1, convert_scalars=True)
+        self.assertEquals(type(interface.reshape(mat, (1,1))), type(mat))
         # Test scalars.
         scalar = interface.scalar_matrix(1, 1, 1)
         self.assertEquals(type(scalar), cvxopt.spmatrix)
@@ -130,6 +135,8 @@ class TestInterfaces(unittest.TestCase):
         mat = interface.const_to_matrix([[1,2,3],[3,4,5]])
         mat = interface.reshape(mat, (6,1))
         self.assertEquals(interface.index(mat, (4,0)), 4)
+        mat = interface.const_to_matrix(1, convert_scalars=True)
+        self.assertEquals(type(interface.reshape(mat, (1,1))), type(mat))
         # index
         mat = interface.const_to_matrix([[1,2,3,4],[3,4,5,6]])
         self.assertEquals( interface.index(mat, (0,1)), 3)
@@ -165,6 +172,8 @@ class TestInterfaces(unittest.TestCase):
         mat = interface.const_to_matrix([[1,2,3],[3,4,5]])
         mat = interface.reshape(mat, (6,1))
         self.assertEquals(interface.index(mat, (4,0)), 4)
+        mat = interface.const_to_matrix(1, convert_scalars=True)
+        self.assertEquals(type(interface.reshape(mat, (1,1))), type(mat))
         # index
         mat = interface.const_to_matrix([[1,2,3,4],[3,4,5,6]])
         self.assertEquals( interface.index(mat, (0,1)), 3)
@@ -195,6 +204,8 @@ class TestInterfaces(unittest.TestCase):
         mat = interface.const_to_matrix([[1,2,3],[3,4,5]])
         mat = interface.reshape(mat, (6,1))
         self.assertEquals(interface.index(mat, (4,0)), 4)
+        mat = interface.const_to_matrix(1, convert_scalars=True)
+        self.assertEquals(type(interface.reshape(mat, (1,1))), type(mat))
         # Test scalars.
         scalar = interface.scalar_matrix(1, 1, 1)
         self.assertEquals(type(scalar), np.ndarray)
@@ -210,3 +221,30 @@ class TestInterfaces(unittest.TestCase):
         self.assertEqual(intf.scalar_value(mat), 1.0)
         # Sign
         self.sign_for_intf(interface)
+
+    def test_conversion_between_intf(self):
+        """Test conversion between every pair of interfaces.
+        """
+        interfaces = [intf.get_matrix_interface(cvxopt.matrix),
+                      intf.get_matrix_interface(cvxopt.spmatrix),
+                      intf.get_matrix_interface(np.ndarray),
+                      intf.get_matrix_interface(np.matrix),
+                      intf.get_matrix_interface(sp.csc_matrix)]
+        cmp_mat = [[1,2,3,4],[3,4,5,6],[-1,0,2,4]]
+        for i in range(len(interfaces)):
+            for j in range(i+1, len(interfaces)):
+                intf1 = interfaces[i]
+                mat1 = intf1.const_to_matrix(cmp_mat)
+                intf2 = interfaces[j]
+                mat2 = intf2.const_to_matrix(cmp_mat)
+                for col in range(len(cmp_mat)):
+                    for row in range(len(cmp_mat[0])):
+                        key = (slice(row, row+1, None),
+                               slice(col, col+1, None))
+                        self.assertEqual(intf1.index(mat1, key),
+                                         intf2.index(mat2, key))
+                        # Convert between the interfaces.
+                        self.assertEqual(cmp_mat[col][row],
+                                         intf1.index(intf1.const_to_matrix(mat2), key))
+                        self.assertEqual(intf2.index(intf2.const_to_matrix(mat1), key),
+                                         cmp_mat[col][row])
