@@ -35,6 +35,10 @@ import unittest
 import math
 import sys
 from cStringIO import StringIO
+# Solvers.
+import scs
+import cvxopt.solvers
+import ecos
 
 class TestProblem(BaseTest):
     """ Unit tests for the expression/expression module. """
@@ -110,6 +114,40 @@ class TestProblem(BaseTest):
         self.assertEqual(A.size, (0, 3))
         self.assertEqual(G.size, (3, 3))
 
+    def test_unpack_results(self):
+        """Test unpack results method.
+        """
+        with self.assertRaises(Exception) as cm:
+            Problem(Minimize(exp(self.a))).unpack_results("blah", None)
+        self.assertEqual(str(cm.exception), "Unknown solver.")
+
+        prob = Problem(Minimize(exp(self.a)), [self.a == 0])
+        args = prob.get_problem_data(s.SCS)
+        results_dict = scs.solve(*args)
+        prob = Problem(Minimize(exp(self.a)), [self.a == 0])
+        prob.unpack_results(s.SCS, results_dict)
+        self.assertAlmostEqual(self.a.value, 0, places=4)
+        self.assertAlmostEqual(prob.value, 1, places=3)
+        self.assertAlmostEqual(prob.status, s.OPTIMAL)
+
+        prob = Problem(Minimize(norm(self.x)), [self.x == 0])
+        args = prob.get_problem_data(s.ECOS)
+        results_dict = ecos.solve(*args)
+        prob = Problem(Minimize(norm(self.x)), [self.x == 0])
+        prob.unpack_results(s.ECOS, results_dict)
+        self.assertItemsAlmostEqual(self.x.value, [0,0])
+        self.assertAlmostEqual(prob.value, 0)
+        self.assertAlmostEqual(prob.status, s.OPTIMAL)
+
+        prob = Problem(Minimize(norm(self.x)), [self.x == 0])
+        args = prob.get_problem_data(s.CVXOPT)
+        results_dict = cvxopt.solvers.conelp(*args)
+        prob = Problem(Minimize(norm(self.x)), [self.x == 0])
+        prob.unpack_results(s.CVXOPT, results_dict)
+        self.assertItemsAlmostEqual(self.x.value, [0,0])
+        self.assertAlmostEqual(prob.value, 0)
+        self.assertAlmostEqual(prob.status, s.OPTIMAL)
+
     # Test silencing and enabling solver messages.
     def test_verbose(self):
         # From http://stackoverflow.com/questions/5136611/capture-stdout-from-a-script-in-python
@@ -1054,3 +1092,26 @@ class TestProblem(BaseTest):
         gamma.value = 1
         prob.solve(solver=s.CVXOPT)
         self.assertEqual(prob.status, s.OPTIMAL)
+
+    def test_parameter_expressions(self):
+        """Test that expressions with parameters are updated properly.
+        """
+        x = Variable()
+        y = Variable()
+        x0 = Parameter()
+        xSquared = x0*x0 + 2*x0*(x - x0)
+
+        # initial guess for x
+        x0.value = 2
+
+        # make the constraint x**2 - y == 0
+        g = xSquared - y
+
+        # set up the problem
+        obj = abs(x - 1)
+        prob = Problem( Minimize( obj ), [ g == 0 ] )
+        prob.solve()
+        x0.value = 1
+        prob.solve()
+        self.assertAlmostEqual(g.value, 0)
+
